@@ -56,9 +56,9 @@ class XMLStats:
     #     'date': '20130414'
     # }
 
-    def __init__(self, access_token, user_agent):
+    def __init__(self, access_token, email):
         self.access_token = access_token
-        self.user_agent = user_agent
+        self.user_agent = "python-xmlstats/0.7 ({email})".format(email)
         urllib.request.install_opener(urllib.request.build_opener(TLS1Handler()))
 
     def make_request(self, host, sport, method, id, format, parameters):
